@@ -301,6 +301,10 @@ class APT_PUBLIC pkgAcquire::Item : public WeakPointable				/*{{{*/
    /** \brief The priority of the item, used for queuing */
    int APT_HIDDEN Priority();
 
+   /** \brief internal clock definitions to avoid typing all that all over the place */
+   void APT_HIDDEN FetchAfter(time_point FetchAfter);
+   time_point APT_HIDDEN FetchAfter();
+
    protected:
    /** \brief The acquire object with which this item is associated. */
    pkgAcquire * const Owner;
