@@ -1231,8 +1231,7 @@ bool pkgProblemResolver::InstOrNewPolicyBroken(pkgCache::PkgIterator I)
    }
 
    // a newly broken policy (recommends/suggests) is a problem
-   if ((Flags[I->ID] & BrokenPolicyAllowed) == 0 &&
-       Cache[I].NowPolicyBroken() == false &&
+   if (Cache[I].NowPolicyBroken() == false &&
        Cache[I].InstPolicyBroken() == true)
    {
       if (Debug == true)
@@ -1357,7 +1356,8 @@ bool pkgProblemResolver::ResolveByKeepInternal()
 	       pkgCache::PkgIterator Pkg = Ver.ParentPkg();
 	       
 	       // It is not keepable
-	       if (Pkg->CurrentVer == 0)
+	       if (Cache[Pkg].InstallVer == 0 ||
+		   Pkg->CurrentVer == 0)
 		  continue;
 
 	       if (not Cache[Pkg].Protect())
@@ -1400,9 +1400,6 @@ bool pkgProblemResolver::ResolveByKeepInternal()
 
    delete[] PList;
 
-   if (Cache.BrokenCount() != 0)
-      return _error->Error(_("Unable to correct problems, you have held broken packages."));
-
    if (Debug)
       Cache.CheckConsistency("keep done");
 
