@@ -1,9 +1,13 @@
 // -*- mode: cpp; mode: fold -*-
+// SPDX-License-Identifier: GPL-2.0+
 // Description								/*{{{*/
 /* ######################################################################
 
    Command Line Class - Sophisticated command line parser
    
+   This file had this historic note, but now includes further changes
+   under the GPL-2.0+:
+
    This source is placed in the Public Domain, do with it what you will
    It was originally written by Jason Gunthorpe <jgg@debian.org>.
    
