@@ -513,7 +513,6 @@ bool pkgTagSection::Scan(const char *Start,unsigned long MaxLength, bool const R
       return false;
 
    pkgTagSectionPrivate::TagData lastTagData(0);
-   lastTagData.EndTag = 0;
    Key lastTagKey = Key::Unknown;
    unsigned int lastTagHash = 0;
    while (Stop < End)
@@ -529,7 +528,7 @@ bool pkgTagSection::Scan(const char *Start,unsigned long MaxLength, bool const R
       if (isspace_ascii(Stop[0]) == 0)
       {
 	 // store the last found tag
-	 if (lastTagData.EndTag != 0)
+	 if (lastTagData.StartValue != 0)
 	 {
 	    if (lastTagKey != Key::Unknown) {
 	       AlphaIndexes[static_cast<size_t>(lastTagKey)] = TagCount;
@@ -579,7 +578,7 @@ bool pkgTagSection::Scan(const char *Start,unsigned long MaxLength, bool const R
       // Double newline marks the end of the record
       if (Stop+1 < End && Stop[1] == '\n')
       {
-	 if (lastTagData.EndTag != 0)
+	 if (lastTagData.StartValue != 0)
 	 {
 	    if (lastTagKey != Key::Unknown) {
 	       AlphaIndexes[static_cast<size_t>(lastTagKey)] = TagCount;
@@ -626,6 +625,11 @@ bool pkgTagSection::Exists(StringView Tag) const
 {
    unsigned int tmp;
    return Find(Tag, tmp);
+}
+bool pkgTagSection::Exists(Key key) const
+{
+   unsigned int tmp;
+   return Find(key, tmp);
 }
 									/*}}}*/
 // TagSection::Find - Locate a tag					/*{{{*/
@@ -669,6 +673,9 @@ bool pkgTagSection::Find(StringView TagView,unsigned int &Pos) const
 bool pkgTagSection::FindInternal(unsigned int Pos, const char *&Start,
 		         const char *&End) const
 {
+   if (unlikely(Pos + 1 >= d->Tags.size() || Pos >= d->Tags.size()))
+      return _error->Error("Internal parsing error");
+
    Start = Section + d->Tags[Pos].StartValue;
    // Strip off the gunk from the end
    End = Section + d->Tags[Pos + 1].StartTag;
@@ -713,9 +720,17 @@ StringView pkgTagSection::Find(Key key) const
 // TagSection::FindRawS - Find a string					/*{{{*/
 StringView pkgTagSection::FindRawInternal(unsigned int Pos) const
 {
+   if (unlikely(Pos + 1 >= d->Tags.size() || Pos >= d->Tags.size()))
+      return _error->Error("Internal parsing error"), "";
+
    char const *Start = (char const *) memchr(Section + d->Tags[Pos].EndTag, ':', d->Tags[Pos].StartValue - d->Tags[Pos].EndTag);
-   ++Start;
    char const *End = Section + d->Tags[Pos + 1].StartTag;
+
+   if (Start == nullptr)
+      return "";
+
+   ++Start;
+
    if (unlikely(Start > End))
       return "";
 
@@ -923,6 +938,8 @@ bool pkgTagSection::FindFlag(unsigned long &Flags, unsigned long Flag,
 									/*}}}*/
 void pkgTagSection::Get(const char *&Start,const char *&Stop,unsigned int I) const/*{{{*/
 {
+   if (unlikely(I + 1 >= d->Tags.size() || I >= d->Tags.size()))
+      abort();
    Start = Section + d->Tags[I].StartTag;
    Stop = Section + d->Tags[I+1].StartTag;
 }
@@ -1039,8 +1056,8 @@ bool pkgTagSection::Write(FileFd &File, char const * const * const Order, std::v
    {
       if (R->Action == Tag::REMOVE)
 	 continue;
-      std::string const name = ((R->Action == Tag::RENAME) ? R->Data : R->Name);
-      if (Exists(name.c_str()))
+      auto const name = ((R->Action == Tag::RENAME) ? R->Data : R->Name);
+      if (Exists(name))
 	 continue;
       if (Order != NULL)
       {
