@@ -5,6 +5,7 @@
  *
  * SPDX-License-Identifier: GPL-2.0+
  */
+#include <config.h>
 
 #include <apt-pkg/debsystem.h>
 #include <apt-pkg/fileutl.h>
@@ -17,10 +18,12 @@
 #include <ostream>
 #include <sstream>
 #include <stack>
+#include <unordered_map>
 
 #include <signal.h>
 #include <sys/socket.h>
 #include <sys/types.h>
+#include <unistd.h>
 
 /**
  * @brief Simple JSON writer
@@ -198,6 +201,33 @@ class APT_HIDDEN JsonWriter
    }
 };
 
+/**
+ * @brief Write a VerFileIterator to a JsonWriter
+ */
+static void verFiletoJson(JsonWriter &writer, CacheFile &, pkgCache::VerFileIterator const &vf)
+{
+   auto pf = vf.File(); // Packages file
+   auto rf = pf.ReleaseFile(); // release file
+
+   writer.beginObject();
+   if (not rf.end()) {
+      if (rf->Archive != 0)
+	 writer.name("archive").value(rf.Archive());
+      if (rf->Codename != 0)
+	 writer.name("codename").value(rf.Codename());
+      if (rf->Version != 0)
+	 writer.name("version").value(rf.Version());
+      if (rf->Origin != 0)
+	 writer.name("origin").value(rf.Origin());
+      if (rf->Label != 0)
+	 writer.name("label").value(rf.Label());
+      if (rf->Site != 0)
+	 writer.name("site").value(rf.Site());
+   }
+
+   writer.endObject();
+}
+
 /**
  * @brief Write a VerIterator to a JsonWriter
  */
@@ -208,6 +238,14 @@ static void verIterToJson(JsonWriter &writer, CacheFile &Cache, pkgCache::VerIte
    writer.name("version").value(Ver.VerStr());
    writer.name("architecture").value(Ver.Arch());
    writer.name("pin").value(Cache->GetPolicy().GetPriority(Ver));
+
+   writer.name("origins");
+   writer.beginArray();
+   for (auto vf = Ver.FileList(); !vf.end(); vf++)
+      if ((vf.File()->Flags & pkgCache::Flag::NotSource) == 0)
+         verFiletoJson(writer, Cache, vf);
+   writer.endArray();
+
    writer.endObject();
 }
 
@@ -230,7 +268,7 @@ static void DpkgChrootDirectory()
 /**
  * @brief Send a notification to the hook's stream
  */
-static void NotifyHook(std::ostream &os, std::string const &method, const char **FileList, CacheFile &Cache, std::set<std::string> const &UnknownPackages)
+static void NotifyHook(std::ostream &os, std::string const &method, const char **FileList, CacheFile &Cache, std::set<std::string> const &UnknownPackages, int hookVersion)
 {
    SortedPackageUniverse Universe(Cache);
    JsonWriter jsonWriter{os};
@@ -242,11 +280,14 @@ static void NotifyHook(std::ostream &os, std::string const &method, const char *
 
    /* Build params */
    jsonWriter.name("params").beginObject();
-   jsonWriter.name("command").value(FileList[0]);
-   jsonWriter.name("search-terms").beginArray();
-   for (int i = 1; FileList[i] != NULL; i++)
-      jsonWriter.value(FileList[i]);
-   jsonWriter.endArray();
+   if (FileList != nullptr)
+   {
+      jsonWriter.name("command").value(FileList[0]);
+      jsonWriter.name("search-terms").beginArray();
+      for (int i = 1; FileList[i] != NULL; i++)
+	 jsonWriter.value(FileList[i]);
+      jsonWriter.endArray();
+   }
    jsonWriter.name("unknown-packages").beginArray();
    for (auto const &PkgName : UnknownPackages)
       jsonWriter.value(PkgName);
@@ -273,7 +314,14 @@ static void NotifyHook(std::ostream &os, std::string const &method, const char *
       switch (Cache[Pkg].Mode)
       {
       case pkgDepCache::ModeInstall:
-	 jsonWriter.name("mode").value("install");
+	 if (Pkg->CurrentVer != 0 && Cache[Pkg].Upgrade() && hookVersion >= 0x020)
+	    jsonWriter.name("mode").value("upgrade");
+	 else if (Pkg->CurrentVer != 0 && Cache[Pkg].Downgrade() && hookVersion >= 0x020)
+	    jsonWriter.name("mode").value("downgrade");
+	 else if (Pkg->CurrentVer != 0 && Cache[Pkg].ReInstall() && hookVersion >= 0x020)
+	    jsonWriter.name("mode").value("reinstall");
+	 else
+	    jsonWriter.name("mode").value("install");
 	 break;
       case pkgDepCache::ModeDelete:
 	 jsonWriter.name("mode").value(Cache[Pkg].Purge() ? "purge" : "deinstall");
@@ -306,7 +354,7 @@ static void NotifyHook(std::ostream &os, std::string const &method, const char *
 static std::string BuildHelloMessage()
 {
    std::stringstream Hello;
-   JsonWriter(Hello).beginObject().name("jsonrpc").value("2.0").name("method").value("org.debian.apt.hooks.hello").name("id").value(0).name("params").beginObject().name("versions").beginArray().value("0.1").endArray().endObject().endObject();
+   JsonWriter(Hello).beginObject().name("jsonrpc").value("2.0").name("method").value("org.debian.apt.hooks.hello").name("id").value(0).name("params").beginObject().name("versions").beginArray().value("0.1").value("0.2").endArray().endObject().endObject();
 
    return Hello.str();
 }
@@ -323,11 +371,10 @@ static std::string BuildByeMessage()
 /// @brief Run the Json hook processes in the given option.
 bool RunJsonHook(std::string const &option, std::string const &method, const char **FileList, CacheFile &Cache, std::set<std::string> const &UnknownPackages)
 {
-   std::stringstream ss;
-   NotifyHook(ss, method, FileList, Cache, UnknownPackages);
-   std::string TheData = ss.str();
+   std::unordered_map<int, std::string> notifications;
    std::string HelloData = BuildHelloMessage();
    std::string ByeData = BuildByeMessage();
+   int hookVersion;
 
    bool result = true;
 
@@ -427,6 +474,20 @@ bool RunJsonHook(std::string const &option, std::string const &method, const cha
 	 goto out;
       }
 
+      if (strstr(line, "\"0.1\""))
+      {
+	 hookVersion = 0x010;
+      }
+      else if (strstr(line, "\"0.2\""))
+      {
+	 hookVersion = 0x020;
+      }
+      else
+      {
+	 _error->Error("Unknown hook version in handshake from hook %s: %s", Opts->Value.c_str(), line);
+	 goto out;
+      }
+
       size = getline(&line, &linesize, F);
       if (size < 0)
       {
@@ -438,9 +499,18 @@ bool RunJsonHook(std::string const &option, std::string const &method, const cha
 	 _error->Error("Expected empty line after handshake from %s, received %s", Opts->Value.c_str(), line);
 	 goto out;
       }
-
-      fwrite(TheData.data(), TheData.size(), 1, F);
-      fwrite("\n\n", 2, 1, F);
+      {
+	 std::string &data = notifications[hookVersion];
+	 if (data.empty())
+	 {
+	    std::stringstream ss;
+	    NotifyHook(ss, method, FileList, Cache, UnknownPackages, hookVersion);
+	    ;
+	    data = ss.str();
+	 }
+	 fwrite(data.data(), data.size(), 1, F);
+	 fwrite("\n\n", 2, 1, F);
+      }
 
       fwrite(ByeData.data(), ByeData.size(), 1, F);
       fwrite("\n\n", 2, 1, F);
@@ -452,6 +522,7 @@ bool RunJsonHook(std::string const &option, std::string const &method, const cha
 	 result = _error->Error("Failure running hook %s", Opts->Value.c_str());
 	 break;
       }
+
    }
    signal(SIGINT, old_sigint);
    signal(SIGPIPE, old_sigpipe);
